@@ -1,11 +1,14 @@
-/*  $Revision: 1.4 $
+/*  $Revision: 1.7 $
 **
 */
+#include <stdio.h>
+#include <sys/types.h>
 #include "configdata.h"
+#include "clibrary.h"
 
 
 #if	defined(NBIO_IOCTL)
-#include <ioctl.h>
+#include <sys/ioctl.h>
 
 /*
 **  Enable or disable non-blocking I/O mode.
@@ -25,10 +28,14 @@ SetNonBlocking(fd, flag)
 
 
 #if	defined(NBIO_FCNTL)
-#include <sys/types.h>
 #include <sys/file.h>
 #include <fcntl.h>
 
+#if	!defined(FNDELAY)
+#define FNDELAY		O_NDELAY
+#endif	/* !defined(FNDELAY) */
+
+
 /*
 **  Enable or disable non-blocking I/O mode.
 */
